@@ -1,5 +1,5 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 from trytond.model import fields
 from trytond.pyson import Eval
 from trytond.pool import Pool, PoolMeta
@@ -59,16 +59,9 @@ class Purchase:
 
     @fields.depends('customer', 'delivery_address')
     def on_change_customer(self):
-        result = {
-            'delivery_address': None,
-            }
-        delivery_address = None
+        self.delivery_address = None
         if self.customer:
-            delivery_address = self.customer.address_get(type='delivery')
-        if delivery_address:
-            result['delivery_address'] = delivery_address.id
-            result['delivery_address.rec_name'] = delivery_address.rec_name
-        return result
+            self.delivery_address = self.customer.address_get(type='delivery')
 
     def get_drop_shipments(self, name):
         DropShipment = Pool().get('stock.shipment.drop')
