@@ -1,5 +1,5 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 from itertools import groupby, chain
 from functools import partial
 from trytond.model import fields
@@ -91,7 +91,7 @@ class SaleLine:
                 and self.supply_on_sale):
             if (self.purchase_request and self.purchase_request.customer
                     and self.purchase_request_state != 'cancel'):
-                return {}
+                return
         return result
 
     def get_purchase_request(self):
